==> zio-aws-rds_3-5.17.129.1-sources.jar: zio/aws/rds/model/DescribeDbClusterSnapshotAttributesResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribeDbClusterSnapshotAttributesResponse(
    dbClusterSnapshotAttributesResult: scala.Option[
      zio.aws.rds.model.DBClusterSnapshotAttributesResult
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbClusterSnapshotAttributesResponse = {
    import DescribeDbClusterSnapshotAttributesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbClusterSnapshotAttributesResponse
      .builder()
      .optionallyWith(
        dbClusterSnapshotAttributesResult.map(value => value.buildAwsValue())
      )(_.dbClusterSnapshotAttributesResult)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse.ReadOnly =
    zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse
      .wrap(buildAwsValue())
}
object DescribeDbClusterSnapshotAttributesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbClusterSnapshotAttributesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse =
      zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse(
        dbClusterSnapshotAttributesResult.map(value => value.asEditable)
      )
    def dbClusterSnapshotAttributesResult: scala.Option[
      zio.aws.rds.model.DBClusterSnapshotAttributesResult.ReadOnly
    ]
    def getDbClusterSnapshotAttributesResult: ZIO[
      Any,
      AwsError,
      zio.aws.rds.model.DBClusterSnapshotAttributesResult.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dbClusterSnapshotAttributesResult",
      dbClusterSnapshotAttributesResult
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbClusterSnapshotAttributesResponse
  ) extends zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse.ReadOnly {
    override val dbClusterSnapshotAttributesResult: scala.Option[
      zio.aws.rds.model.DBClusterSnapshotAttributesResult.ReadOnly
    ] = scala
      .Option(impl.dbClusterSnapshotAttributesResult())
      .map(value =>
        zio.aws.rds.model.DBClusterSnapshotAttributesResult.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbClusterSnapshotAttributesResponse
  ): zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_3-5.17.169.1-sources.jar: zio/aws/rds/model/DescribeDbClusterSnapshotAttributesResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DescribeDbClusterSnapshotAttributesResponse(
    dbClusterSnapshotAttributesResult: Optional[
      zio.aws.rds.model.DBClusterSnapshotAttributesResult
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbClusterSnapshotAttributesResponse = {
    import DescribeDbClusterSnapshotAttributesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbClusterSnapshotAttributesResponse
      .builder()
      .optionallyWith(
        dbClusterSnapshotAttributesResult.map(value => value.buildAwsValue())
      )(_.dbClusterSnapshotAttributesResult)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse.ReadOnly =
    zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse
      .wrap(buildAwsValue())
}
object DescribeDbClusterSnapshotAttributesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbClusterSnapshotAttributesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse =
      zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse(
        dbClusterSnapshotAttributesResult.map(value => value.asEditable)
      )
    def dbClusterSnapshotAttributesResult
        : Optional[zio.aws.rds.model.DBClusterSnapshotAttributesResult.ReadOnly]
    def getDbClusterSnapshotAttributesResult: ZIO[
      Any,
      AwsError,
      zio.aws.rds.model.DBClusterSnapshotAttributesResult.ReadOnly
    ] = AwsError.unwrapOptionField(
      "dbClusterSnapshotAttributesResult",
      dbClusterSnapshotAttributesResult
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbClusterSnapshotAttributesResponse
  ) extends zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse.ReadOnly {
    override val dbClusterSnapshotAttributesResult: Optional[
      zio.aws.rds.model.DBClusterSnapshotAttributesResult.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.dbClusterSnapshotAttributesResult())
      .map(value =>
        zio.aws.rds.model.DBClusterSnapshotAttributesResult.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbClusterSnapshotAttributesResponse
  ): zio.aws.rds.model.DescribeDbClusterSnapshotAttributesResponse.ReadOnly =
    new Wrapper(impl)
}
